@@ -4,7 +4,7 @@ Est.Corr.Hajek <- function(VecY.s, VecX.s, VecPk.s)
   if(! is.vector(VecX.s)              ){stop("VecX.s must be a vector.")                        }
   if(! is.vector(VecPk.s)             ){stop("VecPk.s must be a vector.")                       }
   if(anyNA(VecPk.s)                   ){stop("There are missing values in VecPk.s.")            }
-  if(any(VecPk.s<=0|VecPk.s>1)        ){stop("There are invalid values in VecPk.s.")            }
+  if(min(VecPk.s)<=0|max(VecPk.s)>1   ){stop("There are invalid values in VecPk.s.")            }
   if(anyNA(VecY.s)                    ){stop("There are missing values in VecY.s.")             }
   if(anyNA(VecX.s)                    ){stop("There are missing values in VecX.s.")             }
   n                                    <- length(VecY.s)
